<?php

namespace App\Http\Controllers\API;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Order;
use App\Models\Waste;
use App\Models\Container;
use App\Models\Location;
use App\Models\Customer;

use Illuminate\Support\Facades\Mail;
use App\Mail\OrderEmail;
use App\Mail\VerifyCodeEmail;

use Carbon\Carbon;

class OrderController extends Controller
{
    protected $appDomainUrl;

    public function __construct()
    {
        $this->appDomainUrl = config('services.app_domain_url');
    }

    public function store(Request $request)
    {
        $data = [];
        $errorsList = [];
        $message = '';

        // Check if the request originated from the correct domain
        if ($this->isRequestSecure($request)) {
            // Proceed with logic if the request is secure

            // Validate required fields
            $this->validateField($request, 'address', 'Please enter address', $errorsList);
            $this->validateField($request, 'postcode', 'Please enter postcode', $errorsList);
            $this->validateField($request, 'waste', 'Please select waste type', $errorsList);
            $this->validateField($request, 'bins', 'Please select bin size', $errorsList);
            $this->validateField($request, 'name', 'Please enter name', $errorsList);
            $this->validateField($request, 'email', 'Please enter email', $errorsList);
            $this->validateField($request, 'delivery', 'Please enter delivery date', $errorsList);
            $this->validateField($request, 'collection', 'Please enter collection date', $errorsList);
            $this->validateField($request, 'phone', 'Please enter phone', $errorsList);
            $this->validateField($request, 'payment', 'Please select payment method', $errorsList);
            $this->validateField($request, 'terms', 'Please select terms and conditions', $errorsList);

            $address = $request->input('address');
            $postcode = $request->input('postcode');
            $wasteType = $request->input('waste');
            $binSize = $request->input('bins');
            $name = $request->input('name');
            $phone = $request->input('phone');
            $email = $request->input('email');
            $delivery = $request->input('delivery');
            $collection = $request->input('collection');
            $phone = $request->input('phone');
            $payment = $request->input('payment');
            $terms = $request->input('terms');
            $price = $request->input('price');
            $suburb = $request->input('suburb');
            $instructions = $request->input('instructions');

            if (empty($errorsList)) {

                $request->validate([
                    'address' => ['required', 'string'],
                    'postcode' => ['required', 'string'],
                    'waste' => ['required', 'integer'],
                    'bins' => ['required', 'integer'],
                    'name' => ['required', 'string'],
                    'email' => ['required', 'email'],
                    'phone' => ['required', 'string'],
                    'delivery' => ['required', 'string'],
                    'collection' => ['required', 'string'],
                    'payment' => ['required', 'string'],
                    'terms' => ['required', 'boolean'],
                ]);

                $order = Order::create([
                    'address' => $address,
                    'postcode' => $postcode,
                    'waste' => $wasteType,
                    'bins' => $binSize,
                    'name' => $name,
                    'email' => $email,
                    'phone' => $phone,
                    'delivery' => $delivery,
                    'collection' => $collection,
                    'payment' => $payment,
                    'terms' => $terms,
                    'price' => $price,
                    'suburb' => $suburb,
                    'instructions' => $instructions,
                    'status' => 'Pending',
                ]);

                // If no errors, proceed with the logic
                $message = 'Order created successfully';

                if($order->id) {
                    $data['status'] = true;
                    $data['message'] = $message;
                    $data['order'] = $order->id;

                    $this->sendEmail($order->id);
                }

            } else {
                // If there are errors, return error response
                $data['status'] = false;
                $data['errors'] = $errorsList;
                $data['postcode'] = $postcode;
            }
        } else {
            // If the request is not secure, return error response
            $data['status'] = false;
            $data['errors'] = ['In-Secure call'];
        }

        return response()->json($data);
    }

    public function sendEmail($order_id)
    {
        // $order_id = 10;

        $orderData = Order::where('id',$order_id)->first();
        $data = [];

        $data['id'] = $orderData->id;

        $wasteDetails = Waste::where('id',$orderData->waste)->first();
        $binDetails = Container::where('id',$orderData->bins)->first();
        $locationDetails = Location::where('zip',$orderData->postcode)->first();


        $data['waste'] = $wasteDetails->name;
        $data['bin'] = $binDetails->name;
        $data['delivery'] = date('F j, Y',strtotime($orderData->delivery));
        $data['collection'] = date('F j, Y',strtotime($orderData->collection));

        $data['postcode'] = $locationDetails->zip.' - '.$locationDetails->location;

        $data['name'] = $orderData->name;
        $data['email'] = $orderData->email;
        $data['phone'] = $orderData->phone;
        $data['address'] = $orderData->address;
        $data['suburb'] = $orderData->suburb;
        $data['instructions'] = $orderData->instructions;

        if($orderData->payment == 'delivery') {
            $paymentMethod = 'Pay on Delivery';
        }
        else if($orderData->payment == 'bank') {
            $paymentMethod = 'Pay by Bank';
        }

        $data['payment'] = $paymentMethod;
        $data['price'] = '$'.$orderData->price;

        Mail::to($orderData->email)->send(new OrderEmail($data));

        // print_r($data);

        return 'Email sent successfully!';
    }

    protected function isRequestSecure(Request $request)
    {
        $referer = $request->header('referer');
        return $referer && strpos($referer, $this->appDomainUrl) !== false;
    }

    protected function validateField(Request $request, $field, $errorMessage, &$errorsList)
    {
        if (!$request->has($field) || empty($request->$field)) {
            $errorsList[] = $errorMessage;
        }
    }

    public function checkEmail(Request $request) {
        $data = [];
        $email = $request->input('email');
        $emails = Order::where('email',$email)->first();
        if($emails) {
            $data['status'] = true;
            $data['message'] = 'Please check your email address, we sent you code to verify.';

            $code = $this->generateCode();
            $mailData['code'] = $code;

            $checkCustomer = Customer::firstOrNew(['email' => $email]);
            $checkCustomer->code = $code;
            $checkCustomer->save();

            Mail::to($email)->send(new VerifyCodeEmail($mailData));
        }
        else {
            $data['status'] = false;
            $data['errors'] = "We didn't found your email, please re-check from your previous orders";
        }

        return response()->json($data);
    }

    public function verifyCode(Request $request) {

        $data = [];

        $code = $request->input('code');
        $email = $request->input('email');

        $customerExists = Customer::where('email', $email)
                          ->where('code', $code)
                          ->exists();

        if($customerExists) {
            $data['status'] = true;
            $data['message'] = 'Valid Code';
        }
        else {
            $data['status'] = false;
            $data['error'] = 'Code is not valid';
        }

        return response()->json($data);
    }

    public function getOrders(Request $request) {
        $data = [];

        $code = $request->input('code');
        $email = $request->input('email');
        $customerExists = Customer::where('email', $email)
                          ->where('code', $code)
                          ->exists();
        if($customerExists) {

            $orders = Order::where('email', $email)
            ->select('id', 'status', 'address', 'delivery', 'collection')
            ->get();

            $orders = $orders->map(function ($order) {
                $order->delivery = Carbon::parse($order->delivery)->format('F j, Y');
                $order->collection = Carbon::parse($order->collection)->format('F j, Y');
                return $order;
            });

            $data['status'] = true;
            $data['message'] = $orders;
        }
        else {
            $data['status'] = false;
            $data['error'] = 'No order found';
        }

        return response()->json($data);
    }

    private function generateCode() {
        $length = 6;
        $characters = '0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $code = substr(str_shuffle(str_repeat($characters, $length)), 0, $length);
        return $code;
    }
}
