<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use App\Models\Waste;
use App\Models\Container;

class ContainerController extends Controller
{
    /**
     * All Container Sizes
     */
    public function index() {
        $wastes = Waste::all();
        $containers = Container::all();
        return view('admin.containers.AllContainers',['containers' => $containers, 'wastes' => $wastes]);
    }

    /**
     * Container create form
     */
    public function create() {

        $wastes = Waste::all();
        return view('admin.containers.AddContainer',['wastes' => $wastes]);
    }

    /**
     * Handle an incoming Container data request.
     *
     */
    public function store(Request $request): RedirectResponse
    {
        $imagePath = '';

        // $request->validate([
        //     'name' => ['required', 'string'],
        //     'quantity' => ['required', 'integer'],
        //     'description' => ['required', 'string'],
        // ]);

        $rules = [
            'name' => 'required|string',
            // 'quantity' => 'required|integer',
            'description' => 'required|string',
        ];

        if ($request->hasFile('image')) {
            $rules['image'] = 'image|mimes:jpeg,png,jpg,gif|max:18'; // Max file size in kilobytes (2MB = 2048 KB)
        }

        $request->validate($rules);

        if ($request->hasFile('image')) {
            // $request->validate([
            //     'image' => 'image|mimes:jpeg,png,jpg,gif|max:50', // Adjust max size as needed
            // ]);

            $imagePath = $request->file('image')->store('images', 'public');
        }

        Container::create([
            'name' => $request->name,
            'description' => $request->description,
            'image' => $imagePath ?: '',
            'wastes_qty' => serialize($request->wastes_qty),
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Container added Successfully.');
    }

    /**
     * Display the Edit View
     */
    public function edit($id) {
        $wastes = Waste::all();
        $container = Container::findOrFail($id);

        if(!$container) {
            return redirect()->route('admin.containers')->with('error', 'Container not found.');
        }

        return view('admin.containers.EditContainer',['container' => $container, 'wastes' => $wastes]);
    }

    /**
     * Update Container
     */
    public function update(Request $request, $id) {

        $container = Container::findOrFail($id);

        if(!$container) {
            return redirect()->route('admin.containers')->with('error', 'Container not found.');
        }

        $request->validate([
            'name' => ['required', 'string'],
            'description' => ['required', 'string'],
            'image' => 'image|mimes:jpeg,png,jpg,gif|max:2048',
        ]);

        if ($request->file('image')) {
            $imagePath = $request->file('image')->store('images', 'public');
        }
        else {
            $imagePath = $container->image;
        }

        $container->update([
            'name' => $request->name,
            'description' => $request->description,
            'wastes_qty' => serialize($request->wastes_qty),
            'image' => $imagePath ?: '',
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Container updated Successfully.');
    }

    /**
     * Delete the Container.
     */
    public function delete($id) {
        $container = Container::findOrFail($id);

        if(!$container) {
            return redirect()->route('admin.containers')->with('error', 'Container not found.');
        }

        $container->delete();
        return redirect()->back()->with('success', 'Container deleted Successfully.');
    }
}
