@extends('layouts.master')

@section('title', 'Add Location')

@section('content')
    <!-- Main content -->
    <section class="content">
      <div class="container-fluid">
        <div class="row">
            <div class="col-md-6">
                @if(Session::has('error'))
                    <div class="alert alert-danger">
                        {{ Session::get('error') }}
                    </div>
                @endif
                @if(Session::has('success'))
                    <div class="alert alert-success">
                        {{ Session::get('success') }}
                    </div>
                @endif
                <div class="card card-primary">
                    <x-input-error :messages="$errors->get('city')" class="mt-2 alert-danger" />
                    <x-input-error :messages="$errors->get('location')" class="mt-2 alert-danger" />
                    <x-input-error :messages="$errors->get('zip')" class="mt-2 alert-danger" />
                    <form method="post" action="{{ route('admin.location.store') }}">
                        @csrf
                        <div class="card-body">
                            <div class="form-group">
                                <label for="addLocationCity">Select City</label>
                                <select name="city" id="addLocationCity" class="form-control select2" style="width: 100%;">
                                    @if($cities)
                                    @foreach($cities as $city)
                                    <option value="{{$city->id}}">{{ $city->name }}</option>
                                    @endforeach
                                    @endif
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="addLocationName">Location Name</label>
                                <x-text-input id="addLocationName" class="form-control block mt-1 w-full" type="text" name="location" :value="old('location')" required autofocus autocomplete="name" placeholder="Enter name" />
                            </div>

                            <div class="form-group">
                                <label for="addLocationZipCode">Zip Code</label>
                                <x-text-input id="addLocationZipCode" class="form-control block mt-1 w-full" type="text" name="zip" :value="old('zip')" required placeholder="Enter Zip Code" />
                            </div>

                            <div class="form-group">
                                <label for="addLocationPrice">Price</label>
                                <div class="input-group block">
                                    <div class="input-group-prepend">
                                        <span class="input-group-text">
                                            $
                                        </span>
                                    </div>
                                    <x-text-input id="addLocationPrice" class="form-control block mt-1 w-full" type="text" name="price" :value="old('price')" required autofocus autocomplete="name" placeholder="Enter Price" />
                                </div>
                            </div>

                            <div class="form-group">
                                <label for="enable-disable" class="d-block">Enable/Disable</label>
                                <input type="checkbox" name="status" checked data-bootstrap-switch data-off-color="danger" data-on-color="success" value="enable">
                            </div>

                        </div>

                        <!-- /.card-body -->

                        <div class="card-footer">
                            <button type="submit" class="btn btn-primary">Add Location</button>
                        </div>
                    </form>
                </div>
                <!-- /.card -->
            </div>
        </div>
      </div>
    </section>
    <!-- /.content -->
@endsection

@section('pageJS')
<script>
    $(function () {
        $("input[data-bootstrap-switch]").each(function(){
            $(this).bootstrapSwitch('state', $(this).prop('checked'));
        });
        $('.select2').select2();
    });
</script>
@endsection
